@@ -503,14 +503,8 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
         to_store_df['has_just_rebalanced'] = to_store_df.index.weekday == 0
 
         to_store_df['epoch_number'] = to_store_df['has_just_rebalanced'].cumsum()
-
-        def monthlize_epoch(row):
-            weekly_epoch_number = row['epoch_number']
-            epoch_number = weekly_epoch_number-weekly_epoch_number%4
-            return epoch_number
-
-        to_store_df['monthly_epoch_number'] = to_store_df.apply(monthlize_epoch, axis = 1)
-
+        to_store_df['epoch_number_diff'] = to_store_df['epoch_number'].diff()
+        to_store_df['has_just_rebalanced'] = to_store_df['epoch_number_diff'] >0
         epoch_df = to_store_df[to_store_df['has_just_rebalanced']].copy()
         epoch_df = epoch_df[
             ['epoch_number', me_strat, 'long_expo', 'short_expo', f'{me_strat}_compo']]
@@ -1006,7 +1000,7 @@ def compute_alpha_monthly_metrics(data_df = None, core_tokens=['BTC', 'ETH'], ex
             writer.save()
 
             writer = pd.ExcelWriter(
-                local_root_directory + f'{universe_literal}_kpi_df_ls_strategy.xlsx',
+                local_root_directory + f'{universe_literal}_monthly_kpi_df_ls_strategy.xlsx',
                 engine='xlsxwriter')
             # whole_period_kpi_df.to_excel(writer, sheet_name=frequency)
             btd_kpis = btd_kpis.to_frame()
